@@ -12,10 +12,12 @@ get '/' => sub ($c) {
   my $model = $c->param('model');
   my $name = $c->param('name');
   my $group = $c->param('group');
+  my $fields = $c->param('fields');
   my ($models, $names, $groups, $settings);
   $model = trim($model);
   $name = trim($name);
-  my $synth = Synth::Config->new(model => $model);
+  $fields = trim($fields);
+  my $synth = Synth::Config->new(model => $model, verbose => 1);
   if ($model) {
     # get a specs config file for the synth model
     my $set = './eg/' . $synth->model . '.set';
@@ -23,11 +25,17 @@ get '/' => sub ($c) {
     # get the known groups if there are specs
     $groups = $specs ? $specs->{group} : undef;
     $groups = [ sort @$groups ] if $groups;
-    if ($group) {
-      $settings = $synth->search_settings(group => $group, name => $name);
-    }
-    elsif ($name) {
-      $settings = $synth->search_settings(name => $name);
+    # fetch the things!
+    if ($group || $name || $fields) {
+      my %parameters;
+      $parameters{group} = $group if $group;
+      $parameters{name}  = $name  if $name;
+      my @fields = split /\s*,\s*/, $fields;
+      for my $f (@fields) {
+        my ($x, $y) = split /\s*:\s*/, $f;
+        $parameters{$x} = $y;
+      }
+      $settings = $synth->search_settings(%parameters);
     }
     elsif ($synth->model) {
       $settings = $synth->recall_all;
@@ -46,6 +54,7 @@ get '/' => sub ($c) {
     names    => $names,
     group    => $group,
     groups   => $groups,
+    fields   => $fields,
     settings => $settings,
   );
 } => 'index';
@@ -209,6 +218,13 @@ __DATA__
   </div>
 </div>
 <p></p>
+<div class="row">
+  <div class="col">
+    <label for="fields" class="form-label">Field:</label>
+    <input type="text" name="fields" id="fields" value="<%= $fields %>" class="form-control" placeholder="field1:value1, field2:value2, etc.">
+  </div>
+</div>
+<p></p>
 <div class="row">
   <div class="col">
     <button type="submit" class="btn btn-primary"><i class="fa-solid fa-magnifying-glass"></i> Search</button>
@@ -239,9 +255,9 @@ __DATA__
 &nbsp;
 <b>Name</b>: <%= $setting->{name} %> ,
 <b>Group</b>: <%= $setting->{group} %> ,
-<b>Param</b>: <i><%= $setting->{parameter} %></i> <%= $setting->{control} %>
+<b>Param</b>: <%= $setting->{parameter} %> <b>Control</b>: <i><%= $setting->{control} %></i>
 %   if ($setting->{group_to}) {
-<b>To</b>: <i><%= $setting->{param_to} %></i> of <%= $setting->{group_to} %>
+<b>To</b>: <%= $setting->{param_to} %> of <%= $setting->{group_to} %>
 %   }
 %   if ($setting->{value}) {
 ,
